# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: plugin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cplugin.proto\x12\x06plugin\"F\n\rPluginRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12%\n\ninput_args\x18\x02 \x01(\x0b\x32\x11.plugin.InputArgs\"R\n\x0ePluginResponse\x12\n\n\x02id\x18\x01 \x01(\x05\x12%\n\nreturn_val\x18\x02 \x01(\x0b\x32\x11.plugin.ReturnVal\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"\x80\x02\n\tInputArgs\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.plugin.InputArgs.HeadersEntry\x12-\n\x06params\x18\x02 \x03(\x0b\x32\x1d.plugin.InputArgs.ParamsEntry\x12\x0c\n\x04\x62ody\x18\x03 \x01(\x0c\x1a\x42\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.plugin.StringList:\x02\x38\x01\x1a\x41\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.plugin.StringList:\x02\x38\x01\"\x81\x02\n\tReturnVal\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.plugin.ReturnVal.HeadersEntry\x12-\n\x06params\x18\x02 \x03(\x0b\x32\x1d.plugin.ReturnVal.ParamsEntry\x12\r\n\x05value\x18\x03 \x01(\t\x1a\x42\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.plugin.StringList:\x02\x38\x01\x1a\x41\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.plugin.StringList:\x02\x38\x01\"6\n\x0cRegisterArgs\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_secure\x18\x02 \x01(\x08\":\n\rRegisterReply\x12)\n\tendpoints\x18\x01 \x03(\x0b\x32\x16.plugin.PluginEndpoint\"\x88\x01\n\x0ePluginEndpoint\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x12\x11\n\tuses_auth\x18\x04 \x01(\x08\x12\x15\n\rexpected_args\x18\x05 \x01(\t\x12\x15\n\rexpected_body\x18\x06 \x01(\t\x12\x17\n\x0f\x65xpected_output\x18\x07 \x01(\t2\x7f\n\rPluginService\x12\x37\n\x08Register\x12\x14.plugin.RegisterArgs\x1a\x15.plugin.RegisterReply\x12\x35\n\x04\x43\x61ll\x12\x15.plugin.PluginRequest\x1a\x16.plugin.PluginResponseBKZIgithub.com/intel-innersource/frameworks.automation.dtac.agent/api/grpc/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'plugin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/intel-innersource/frameworks.automation.dtac.agent/api/grpc/go'
  _INPUTARGS_HEADERSENTRY._options = None
  _INPUTARGS_HEADERSENTRY._serialized_options = b'8\001'
  _INPUTARGS_PARAMSENTRY._options = None
  _INPUTARGS_PARAMSENTRY._serialized_options = b'8\001'
  _RETURNVAL_HEADERSENTRY._options = None
  _RETURNVAL_HEADERSENTRY._serialized_options = b'8\001'
  _RETURNVAL_PARAMSENTRY._options = None
  _RETURNVAL_PARAMSENTRY._serialized_options = b'8\001'
  _globals['_PLUGINREQUEST']._serialized_start=24
  _globals['_PLUGINREQUEST']._serialized_end=94
  _globals['_PLUGINRESPONSE']._serialized_start=96
  _globals['_PLUGINRESPONSE']._serialized_end=178
  _globals['_STRINGLIST']._serialized_start=180
  _globals['_STRINGLIST']._serialized_end=208
  _globals['_INPUTARGS']._serialized_start=211
  _globals['_INPUTARGS']._serialized_end=467
  _globals['_INPUTARGS_HEADERSENTRY']._serialized_start=334
  _globals['_INPUTARGS_HEADERSENTRY']._serialized_end=400
  _globals['_INPUTARGS_PARAMSENTRY']._serialized_start=402
  _globals['_INPUTARGS_PARAMSENTRY']._serialized_end=467
  _globals['_RETURNVAL']._serialized_start=470
  _globals['_RETURNVAL']._serialized_end=727
  _globals['_RETURNVAL_HEADERSENTRY']._serialized_start=334
  _globals['_RETURNVAL_HEADERSENTRY']._serialized_end=400
  _globals['_RETURNVAL_PARAMSENTRY']._serialized_start=402
  _globals['_RETURNVAL_PARAMSENTRY']._serialized_end=467
  _globals['_REGISTERARGS']._serialized_start=729
  _globals['_REGISTERARGS']._serialized_end=783
  _globals['_REGISTERREPLY']._serialized_start=785
  _globals['_REGISTERREPLY']._serialized_end=843
  _globals['_PLUGINENDPOINT']._serialized_start=846
  _globals['_PLUGINENDPOINT']._serialized_end=982
  _globals['_PLUGINSERVICE']._serialized_start=984
  _globals['_PLUGINSERVICE']._serialized_end=1111
# @@protoc_insertion_point(module_scope)
